<?php 
/*
Plugin Name: Featured Image Import/Export
Plugin URI: https://labs.freddielore.com/
Description: Smart SEO CSV Import/Export add-on to export/import featured images by URL
Version: 1.1.0
Author: Freddie Lore
Author URI: https://labs.freddielore.com/
License: GPL2
*/

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

require_once( plugin_dir_path(__FILE__) . '/lib/class.logger.php'); 
require_once( plugin_dir_path(__FILE__) . '/lib/class.updater.php'); 

define( 'SSFIU_VERSION', '1.1.0' );
define( 'SSFIU_SLUG', plugin_basename(__FILE__) ); 
define( 'SSFIU_UPDATE_URL', 'http://www.freddielore.com/plugin-api/smart-seo-featured-image-by-url/smart-seo-featured-image-by-url.php' );

add_action( 'init', 'fsl_featured_image_by_url_activator' );
function fsl_featured_image_by_url_activator(){
	$plugin = new SmartSEO_Featured_Image_Updater( SSFIU_VERSION, SSFIU_UPDATE_URL, SSFIU_SLUG );
}

// add feactured_image column in CSV
add_filter( 'smart_seo_export_fields', 'fsl_export_other_custom_fields', 8, 1 );
function fsl_export_other_custom_fields( $fields ){
	$fields[] = array( 'featured_image', 'fsl_get_featuredimage' ); 
	return $fields;
}

function fsl_get_featuredimage( $post ){
	if( has_post_thumbnail( $post->ID ) ){
		$img = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'full' );
		return $img[0];
	}
	else{
		return "";
	}
}

// import featured_image by URL 
add_action( 'smart_seo_import_update', 'fsl_import_featured_image_by_url', 10, 2 );
function fsl_import_featured_image_by_url($post_id, $data){
	
	$fsl_log = new FL_FEATURED_IMAGE_LOGGER( FL_UPLOADS . '/featured-images-' . date('d-M-Y') . '.log' );

	if( !empty( $data['featured_image'] ) ){

		// retrieve attachment id if file exists
		$attach_id = fsl_is_media_exists( $data['featured_image'] );

		if( $attach_id ){	
			set_post_thumbnail( $post_id, $attach_id );
		}
		else{
			$insert = fsl_set_featured_image( $data['featured_image'], $post_id );
			if( !$insert ){
				$fsl_log->error( 'Unable to set featured image to `' . $post_id . '`' );
			}
		}
	}

	
}


function fsl_set_featured_image( $image_url, $post_id ){
	// Add Featured Image to Post
	$image_name       =  basename( $image_url );	//preg_replace( '/.[^.]*$/', '', basename( $url ) );
	$upload_dir       = wp_upload_dir(); // Set upload folder
	$image_data       = file_get_contents($image_url); // Get image data
	$unique_file_name = wp_unique_filename( $upload_dir['path'], $image_name ); // Generate unique name
	$filename         = basename( $unique_file_name ); // Create image file name

	// Check folder permission and define file location
	if( wp_mkdir_p( $upload_dir['path'] ) ) {
	    $file = $upload_dir['path'] . '/' . $filename;
	} else {
	    $file = $upload_dir['basedir'] . '/' . $filename;
	}

	// Create the image  file on the server
	file_put_contents( $file, $image_data );

	// Check image file type
	$wp_filetype = wp_check_filetype( $filename, null );

	// Set attachment data
	$attachment = array(
	    'post_mime_type' => $wp_filetype['type'],
	    'post_title'     => sanitize_file_name( $filename ),
	    'post_content'   => '',
	    'post_status'    => 'inherit'
	);

	// Create the attachment
	$attach_id = wp_insert_attachment( $attachment, $file, $post_id );

	// Include image.php
	require_once(ABSPATH . 'wp-admin/includes/image.php');

	// Define attachment metadata
	$attach_data = wp_generate_attachment_metadata( $attach_id, $file );

	// Assign metadata to attachment
	wp_update_attachment_metadata( $attach_id, $attach_data );

	// And finally assign featured image to post
	return set_post_thumbnail( $post_id, $attach_id );

}

function fsl_is_media_exists($url){

	$filename = basename($url);
    global $wpdb;
    $query = "SELECT ID FROM {$wpdb->posts} WHERE guid LIKE '%/$filename'";

    $result = $wpdb->get_row($wpdb->prepare("SELECT ID FROM {$wpdb->posts} WHERE guid LIKE '%/$filename'")); 

    if( !empty($result) ){
    	return $result->ID; 
    }
    else{
    	$result = $wpdb->get_row($wpdb->prepare("SELECT ID FROM {$wpdb->posts} WHERE post_title LIKE '%$filename'")); 
    	if( !empty($result) ){
	    	return $result->ID; 
	    }
    }

    return false;

}


// add_action( 'wp_footer', 'fsl_debugging' );
// function fsl_debugging(){


// 	// $url = 'http://demo.freddielore.com/wp-demo/wp-content/uploads/2020/06/teacher2.jpg';
// 	$url = 'http://demo.freddielore.com/wp-demo/wp-content/uploads/2020/05/hoodie_23_front-1-1.jpg';

// 	$found = fsl_is_media_exists($file);
// 	if( $found ){
// 		echo $file. ' found with ID# ' . $found;
// 	}
// 	else{
// 		echo 'Not found';
// 	}
// }

?>